@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11227 2018-09-10 10:53:39Z Lavender $
+# $Id: cms_plugins.py 11237 2018-10-04 12:45:49Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,18 +12,20 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-09-10 19:53:39 +0900 (週一, 10 九月 2018) $
-# $Revision: 11227 $
+# $Date: 2018-10-04 21:45:49 +0900 (週四, 04 十月 2018) $
+# $Revision: 11237 $
 
 from django.db.models import Count
 from django.template.loader import select_template
+from django.db.models import Q
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from oscar.core.loading import get_model
 
 from Zephyrus.cms_oscar import settings 
-from Zephyrus.cms_oscar.models import OscarFeatured, OscarLatest, OscarOffer
+from Zephyrus.cms_oscar.models import (
+    OscarFeatured, OscarLatest, OscarOffer, OR, AND)
 from Zephyrus.cms_oscar.forms import OscarFeaturedForm, OscarLatestForm
 
 
@@ -51,15 +53,41 @@ class FeaturedPlugin(CMSPluginBase):
         ])
 
     def render(self, context, instance, placeholder):
+        catagories = instance.catagory.all()
+        query = None
+
+        # category
+        if catagories:
+            for c in catagories:
+                if query:
+                    if instance.filterMethod == OR:
+                        query = query | Q(product__categories__id=c.id)
+                    else:
+                        query = query & Q(product__categories__id=c.id)
+                else:
+                    query = Q(product__categories__id=c.id)
+
+        # tag
         if hasTags:
             if instance.tag:
-                queryset = ProductRecord.objects.filter(
-                    product__tags__id__in=[instance.tag])
+                tags = [int(t) for t in instance.tag.split(",")]
             else:
-                queryset = ProductRecord.objects.all()
+                tags = []
+
+            if tags:
+                for t in tags:
+                    if query:
+                        if instance.filterMethod == OR:
+                            query = query | Q(product__tags__id=t)
+                        else:
+                            query = query & Q(product__tags__id=t)
+                    else:
+                        query = Q(product__tags__id=t)
+
+        if query:
+            queryset = ProductRecord.objects.filter(query)
         else:
             queryset = ProductRecord.objects.all()
-        
 
         if queryset.count() >= instance.limit:
             topViewProducts = \
@@ -87,14 +115,41 @@ class LatestPlugin(CMSPluginBase):
         ])
 
     def render(self, context, instance, placeholder):
+        catagories = instance.catagory.all()
+        query = None
+
+        # category
+        if catagories:
+            for c in catagories:
+                if query:
+                    if instance.filterMethod == OR:
+                        query = query | Q(categories__id=c.id)
+                    else:
+                        query = query & Q(categories__id=c.id)
+                else:
+                    query = Q(categories__id=c.id)
+
+        # tag
         if hasTags:
             if instance.tag:
-                queryset = Product.objects.filter(
-                    tags__id__in=[instance.tag])
+                tags = [int(t) for t in instance.tag.split(",")]
             else:
-                queryset = Product.objects.all()
+                tags = []
+
+            if tags:
+                for t in tags:
+                    if query:
+                        if instance.filterMethod == OR:
+                            query = query | Q(tags__id=t)
+                        else:
+                            query = query & Q(tags__id=t)
+                    else:
+                        query = Q(tags__id=t)
+
+        if query:
+            queryset = Product.objects.filter(query)
         else:
-            queryset = ProductRecord.objects.all()
+            queryset = Product.objects.all()
 
         if queryset.count() >= instance.limit:
             products = queryset.order_by('-date_updated')[:instance.limit]
