@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: BuildBoilerplateTest.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: BuildBoilerplateTest.py 11218 2018-09-02 02:13:29Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-09-02 11:13:29 +0900 (週日, 02 九月 2018) $
+# $Revision: 11218 $
 
 import os
 import sys
@@ -187,8 +187,8 @@ class BuildBoilerplateTest(unittest.TestCase):
         conn = sqlite3.connect('Zephyrus.db')
         c = conn.cursor()
         c.execute(
-            "SELECT count(free_link) FROM cmsplugin_filer_image_filerimage "
-            "where free_link = \"http://127.0.0.1:1234\";")
+            "SELECT count(link_url) FROM djangocms_picture_picture "
+            "where link_url = \"http://127.0.0.1:1234\";")
         pluginCount = c.fetchall()[0][0]
         c.close()
         conn.close()
@@ -196,7 +196,7 @@ class BuildBoilerplateTest(unittest.TestCase):
         # 因為 jenkins 跑兩次的關係導致 db 資料變兩倍
         # 因此判斷有沒有 JOB_NAME (代表在 jenkins 上)
         if 'JOB_NAME' in os.environ:
-            self.assertEqual(pluginCount, 4)
+            self.assertEqual(pluginCount, 3)
         else:
             self.assertEqual(pluginCount, 2)
         self.reset()
